@@ -31,6 +31,27 @@ class Resource(object):
   def reader(self):
     return self.__class__.Reader(self.filename)
 
+class Pickle(Resource):
+  class Writer(object):
+    def __init__(self, f):
+      self.file = FS.open(f, 'w')
+      self.data = {}
+
+    def __del__(self):
+      self.file.write(cPickle.dumps(self.data))
+      self.file.close()
+
+    def add(self, k, v):
+      self.data[k] = v
+
+  class Reader(object):
+    def __init__(self, f):
+      self.data = cPickle.loads(FS.open(f))
+
+    def __iter__(self):
+      for k,v in self.data:
+        yield k, v
+
 class CSV(Resource):
   class Writer(object):
     def __init__(self, f):
@@ -105,7 +126,7 @@ class Zip(Resource):
     
     def __iter__(self):
       for filename in self.zip.namelist():
-        data = self.zip.FS.open(filename, 'r').read()
+        data = self.zip.open(filename, 'r').read()
         yield filename, data
   
   class Writer(object):
@@ -116,7 +137,7 @@ class Zip(Resource):
       self.zip.close()
     
     def add(self, k, v):
-      lf = self.zip.FS.open(k, 'w')
+      lf = self.zip.open(k, 'w')
       lf.write(v)
       lf.close()
   
